@@ -4,7 +4,8 @@
  * Author:   Georg Fleischmann
  *
  * Created:  2003-03-23
- * Modified: 2015-01-26 (equatorial positions added)
+ * Modified: 2015-08-17 (periSwitches added)
+ *           2015-01-26 (equatorial positions added)
  *           2014-11-21 (heliocentric position added)
  *
  * This program is free software; you can redistribute it and/or
@@ -33,11 +34,13 @@
 #include "../../Cenon/PreferencesPanel.subproj/PreferencesMethods.h"
 
 #define Prefs_ShowAstroPanel	( ([[[NSUserDefaults standardUserDefaults] \
-                                    objectForKey:@"astroShowPanel"] isEqual:@"YES"]) ? YES : NO )
+                                    objectForKey:@"astroShowPanel"]     isEqual:@"YES"]) ? YES : NO )
 #define Prefs_Colorful          ( ([[[NSUserDefaults standardUserDefaults] \
-                                    objectForKey:@"astroColorful"] isEqual:@"YES"]) ? YES : NO )
+                                    objectForKey:@"astroColorful"]      isEqual:@"YES"]) ? YES : NO )
 #define Prefs_DegreesMinutes	( ([[[NSUserDefaults standardUserDefaults] \
                                     objectForKey:@"astroDegreesMinutes"] isEqual:@"YES"]) ? YES : NO )
+#define Prefs_FractalScale      ( ([[[NSUserDefaults standardUserDefaults] \
+                                    objectForKey:@"astroFractalScale"]  isEqual:@"YES"]) ? YES : NO )
 
 #define Prefs_Topocentric       ( ([[[NSUserDefaults standardUserDefaults] \
                                     objectForKey:@"astroTopocentricPosition"] isEqual:@"YES"]) ? YES : NO )
@@ -73,6 +76,7 @@
 #define Prefs_AstroFont		[[NSUserDefaults standardUserDefaults] objectForKey:@"astroFont"]
 #define Prefs_Objects		[[NSUserDefaults standardUserDefaults] objectForKey:@"astroObjects"]
 #define Prefs_Nodes         [[NSUserDefaults standardUserDefaults] objectForKey:@"astroNodes"]
+#define Prefs_Peri          [[NSUserDefaults standardUserDefaults] objectForKey:@"astroPeri"]
 #define Prefs_AstroInterval	[[[NSUserDefaults standardUserDefaults] objectForKey:@"astroInterval"] intValue]
 
 /* switches in generalSwitches */
@@ -80,7 +84,8 @@ typedef enum
 {
     SWITCH_SHOWASTROPANEL  =  0,
     SWITCH_COLORFUL        =  1,	// use colors for house tips etc.
-    SWITCH_DEGREESMINUTES  =  2
+    SWITCH_DEGREESMINUTES  =  2,    // degree notation: 123.45 / degree, minutes, seconds
+    SWITCH_FRACTALSCALE    =  3     // Fractal Edition: display fractions, not degrees
 }AstroGeneralSwitches;
 
 /* switches in objectSwitches */
@@ -121,42 +126,45 @@ typedef enum
 @interface AstroController:NSObject <PreferencesMethods>
 {
     /* Preferences Pane */
-    IBOutlet NSBox      *box;           // the Astro Preferences box
-    IBOutlet NSBox      *subBox;        // the box for sub-modules
-    IBOutlet NSMatrix   *menuMatrix;    // the menu items
+    IBOutlet NSBox      *box;               // the Astro Preferences box
+    IBOutlet NSBox      *subBox;            // the box for sub-modules
+    IBOutlet NSMatrix   *menuMatrix;        // the menu items
 
     /* General */
-    id boxGeneral;
-    id generalSwitches;     // the switches
-    id datePopup;           // the date format popup
-    id fontPopup;           // the font popup
+    IBOutlet NSBox      *boxGeneral;
+    IBOutlet NSMatrix   *generalSwitches;   // the switches
+    IBOutlet id         datePopup;          // the date format popup
+    IBOutlet id         fontPopup;          // the font popup
 
     /* Objects */
-    id boxObjects;
-    id objectSwitches;      // switch options for objects
-    id object1Switches;     // planets
-    id nodeSwitches;        // planet nodes
-    id object2Switches;     // moon nodes and asteroids
+    IBOutlet NSBox      *boxObjects;
+    IBOutlet NSMatrix   *objectSwitches;     // switch options for objects
+    IBOutlet NSMatrix   *object1Switches;    // planets
+    IBOutlet NSMatrix   *nodeSwitches;       // planet nodes
+    IBOutlet NSMatrix   *periSwitches;       // planet perihelion
+    IBOutlet NSMatrix   *object2Switches;    // moon nodes and asteroids
 
     /* Chart */
-    id boxChart;            // the view with the chart preferences
-    id bgColorWell;         // color well for background color
-    id chartSwitches;       // the chart switches
-    id chartIntervalField;	// time interval
+    IBOutlet NSBox      *boxChart;          // the view with the chart preferences
+    IBOutlet id         bgColorWell;        // color well for background color
+    IBOutlet NSMatrix   *chartSwitches;     // the chart switches
+    IBOutlet id         chartIntervalField; // time interval
 
     /* Map */
     //id boxMap;	// the view with the map preferences
 
-    NSMutableArray	*prefViews;	// preferences modules (boxGeneral, boxObjects, boxChart, ...)
+    NSMutableArray      *prefViews; // preferences modules (boxGeneral, boxObjects, boxChart, ...)
 }
 
-- (void)set:sender;
-- (void)setGeneral:sender;
-- (void)setObjects:sender;
-- (void)setChart:sender;
-//- (void)setMap:sender;
+- (id)generalSwitches;                  // for outside access
 
-- (void)setLevel:sender;
+- (IBAction)set:sender;
+- (IBAction)setGeneral:sender;
+- (IBAction)setObjects:sender;
+- (IBAction)setChart:sender;
+//- (IBAction)setMap:sender;
+
+- (IBAction)setLevel:sender;
 
 @end
 
