@@ -1,11 +1,12 @@
 /* AstroController.m
  * Astrology Preferences controller
  *
- * Copyright (C) 1999-2015 by Cenon GmbH
+ * Copyright (C) 1999-2015 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * Created:  2003-03-23
- * Modified: 2015-01-26 (equatorial positions)
+ * Modified: 2015-10-29 (SWITCH_FRACTALSCALE, -generalSwitches)
+ *           2015-01-26 (equatorial positions)
  *           2014-12-13 (select "General" switch)
  *           2014-11-21 (heliocentric position added)
  *
@@ -30,6 +31,7 @@
 
 #include <AppKit/AppKit.h>
 #include "AstroController.h"
+#include "../../Cenon/App.h"
 #include "../../Cenon/functions.h"
 #include "../../Cenon/PreferencesPanel.subproj/NotificationNames.h"
 #include "../AstroPrincipal.h"
@@ -106,6 +108,20 @@
     [fontPopup setTarget:self];             // set the target
     [fontPopup setAction:@selector(set:)];	// set the action
 
+    /* check for existance of Fractal bundle to enable fractal scale switch */
+    {   NSArray     *modules = [(App*)NSApp modules];
+        int         i;
+
+        for ( i=0; i < [modules count]; i++ )
+        {   NSBundle    *bundle = [modules objectAtIndex:i];
+
+            if ( [[[bundle principalClass] className] hasPrefix:@"Fractal"] )
+            {   [[generalSwitches cellAtRow:SWITCH_FRACTALSCALE column:0] setEnabled:YES];
+                break;
+            }
+        }
+    }
+
     /* Objects */
     if ( ![NSBundle loadNibNamed:@"AstroObjects" owner:self] )
         NSLog(@"Cannot load 'AstroObjects' interface file");
@@ -125,7 +141,7 @@
     [notificationCenter postNotificationName:AstroPrefsCallToAddItemsNotification object:self];
 
     [menuMatrix selectCellAtRow:0 column:0];
-    [[menuMatrix selectedCell] setState:1]; // shouldn't this be done by the mehtod before ?
+    [(NSCell*)[menuMatrix selectedCell] setState:1];    // shouldn't this be done by the mehtod before ?
 }
 
 - (NSImage*)icon
@@ -153,6 +169,11 @@
 // end methods from protocol
 
 
+- (id)generalSwitches
+{
+    return generalSwitches;
+}
+
 /* select level
  * created: 2006-04-27
  */
@@ -172,7 +193,7 @@
 - (void)update:sender
 {   id          defaults = [NSUserDefaults standardUserDefaults];
     int         i;
-    NSArray     *objects, *nodes, *objects1 = OBJECTS_1, *objects2 = OBJECTS_2;
+    NSArray     *objects, *nodes, *apsides, *objects1 = OBJECTS_1, *objects2 = OBJECTS_2;
     NSArray     *dateFormats = [[AstroDate sharedInstance] dateFormats];
     NSString    *string;
 
@@ -193,50 +214,58 @@
         [fontPopup selectItemAtIndex:0];
 #endif
 
-    [[generalSwitches cellAtRow:SWITCH_SHOWASTROPANEL column:0]
-      setState:([[defaults objectForKey:@"astroShowPanel"] isEqual:@"YES"]) ? 1 : 0];
-    [[generalSwitches cellAtRow:SWITCH_COLORFUL column:0]
-      setState:([[defaults objectForKey:@"astroColorful"] isEqual:@"YES"]) ? 1 : 0];
-    [[generalSwitches cellAtRow:SWITCH_DEGREESMINUTES column:0]
+    [(NSCell*)[generalSwitches cellAtRow:SWITCH_SHOWASTROPANEL column:0]
+      setState:([[defaults objectForKey:@"astroShowPanel"]      isEqual:@"YES"]) ? 1 : 0];
+    [(NSCell*)[generalSwitches cellAtRow:SWITCH_COLORFUL column:0]
+      setState:([[defaults objectForKey:@"astroColorful"]       isEqual:@"YES"]) ? 1 : 0];
+    [(NSCell*)[generalSwitches cellAtRow:SWITCH_DEGREESMINUTES column:0]
       setState:([[defaults objectForKey:@"astroDegreesMinutes"] isEqual:@"YES"]) ? 1 : 0];
+    [(NSCell*)[generalSwitches cellAtRow:SWITCH_FRACTALSCALE column:0]
+      setState:([[defaults objectForKey:@"astroFractalScale"]   isEqual:@"YES"]) ? 1 : 0];
 
     /* Objects */
-    [[objectSwitches cellAtRow:SWITCH_TOPOCENTRIC column:0]
+    [(NSCell*)[objectSwitches cellAtRow:SWITCH_TOPOCENTRIC column:0]
       setState:([[defaults objectForKey:@"astroTopocentricPosition"] isEqual:@"YES"]) ? 1 : 0];
-    [[objectSwitches cellAtRow:SWITCH_HELIOCENTRIC column:0]
+    [(NSCell*)[objectSwitches cellAtRow:SWITCH_HELIOCENTRIC column:0]
      setState:([[defaults objectForKey:@"astroHeliocentricPosition"] isEqual:@"YES"]) ? 1 : 0];
-    [[objectSwitches cellAtRow:SWITCH_EQUATORIAL column:0]
-     setState:([[defaults objectForKey:@"astroEquatorialPosition"] isEqual:@"YES"]) ? 1 : 0];
-    [[objectSwitches cellAtRow:SWITCH_MEANNODES column:0]
-      setState:([[defaults objectForKey:@"astroMeanNodes"] isEqual:@"YES"]) ? 1 : 0];
+    [(NSCell*)[objectSwitches cellAtRow:SWITCH_EQUATORIAL column:0]
+     setState:([[defaults objectForKey:@"astroEquatorialPosition"]  isEqual:@"YES"]) ? 1 : 0];
+    [(NSCell*)[objectSwitches cellAtRow:SWITCH_MEANNODES column:0]
+      setState:([[defaults objectForKey:@"astroMeanNodes"]          isEqual:@"YES"]) ? 1 : 0];
     objects = [defaults objectForKey:@"astroObjects"];
     for (i=0; i<(int)[objects1 count]; i++)	// set Planet switches
     {
-        [[object1Switches cellAtRow:i column:0]
+        [(NSCell*)[object1Switches cellAtRow:i column:0]
              setState:[objects containsObject:[objects1 objectAtIndex:i]]];
     }
     nodes = [defaults objectForKey:@"astroNodes"];
     for (i=0; i<(int)[objects1 count]; i++)	// set Node switches
     {
-        [[nodeSwitches cellAtRow:i column:0]
+        [(NSCell*)[nodeSwitches cellAtRow:i column:0]
              setState:[nodes containsObject:[objects1 objectAtIndex:i]]];
     }
+    apsides = [defaults objectForKey:@"astroPeri"];
+    for (i=0; i<(int)[objects1 count]; i++)	// set Perihelion switches
+    {
+        [(NSCell*)[periSwitches cellAtRow:i column:0]
+         setState:[apsides containsObject:[objects1 objectAtIndex:i]]];
+    }
     for (i=0; i<(int)[objects2 count]; i++)	// set other objects switches
     {
-        [[object2Switches cellAtRow:i column:0]
+        [(NSCell*)[object2Switches cellAtRow:i column:0]
              setState:[objects containsObject:[objects2 objectAtIndex:i]]];
     }
 
     /* Chart */
-    [[chartSwitches cellAtRow:SWITCH_SHOWRETROGRADE column:0]
+    [(NSCell*)[chartSwitches cellAtRow:SWITCH_SHOWRETROGRADE column:0]
       setState:([[defaults objectForKey:@"astroShowRetrograde"] isEqual:@"YES"]) ? 1 : 0];
-    [[chartSwitches cellAtRow:SWITCH_LOCALSCALE column:0]
-      setState:([[defaults objectForKey:@"astroLocalScale"] isEqual:@"YES"]) ? 1 : 0];
-    [[chartSwitches cellAtRow:SWITCH_SHOWDECLINATION column:0]
+    [(NSCell*)[chartSwitches cellAtRow:SWITCH_LOCALSCALE column:0]
+      setState:([[defaults objectForKey:@"astroLocalScale"]     isEqual:@"YES"]) ? 1 : 0];
+    [(NSCell*)[chartSwitches cellAtRow:SWITCH_SHOWDECLINATION column:0]
       setState:([[defaults objectForKey:@"astroShowDeclination"] isEqual:@"YES"]) ? 1 : 0];
-    [[chartSwitches cellAtRow:SWITCH_SHOWASPECTGEO column:0]
+    [(NSCell*)[chartSwitches cellAtRow:SWITCH_SHOWASPECTGEO column:0]
       setState:([[defaults objectForKey:@"Prefs_ShowAspectGeo"] isEqual:@"YES"]) ? 1 : 0];
-    [[chartSwitches cellAtRow:SWITCH_ACFIX column:0]
+    [(NSCell*)[chartSwitches cellAtRow:SWITCH_ACFIX column:0]
       setState:([[defaults objectForKey:@"astroACFix"] isEqual:@"YES"]) ? 1 : 0];
     if ( (string = [defaults objectForKey:@"astroInterval"]) )
         [chartIntervalField setStringValue:string];
@@ -249,10 +278,10 @@
 /* set General defaults
  */
 - (void)setGeneral:sender
-{   NSString	*string;
-    id		defaults = [NSUserDefaults standardUserDefaults];
-    int		i;
-    NSArray	*dateFormats = [[AstroDate sharedInstance] dateFormats];
+{   NSString    *string;
+    id          defaults = [NSUserDefaults standardUserDefaults];
+    int         i;
+    NSArray     *dateFormats = [[AstroDate sharedInstance] dateFormats];
 
     /* date format */
     i = [datePopup indexOfSelectedItem];
@@ -265,17 +294,21 @@
         [defaults setObject:string forKey:@"astroFont"];
 
     /* show Astro Panel */
-    string = ([[generalSwitches cellAtRow:SWITCH_SHOWASTROPANEL column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[generalSwitches cellAtRow:SWITCH_SHOWASTROPANEL column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroShowPanel"]] )
         [defaults setObject:string forKey:@"astroShowPanel"];
-    /* show degrees with minutes */
-    string = ([[generalSwitches cellAtRow:SWITCH_DEGREESMINUTES column:0] state]) ? @"YES" : @"NO";
-    if ( ![string isEqual:[defaults objectForKey:@"astroDegreesMinutes"]] )
-        [defaults setObject:string forKey:@"astroDegreesMinutes"];
     /* make colorful */
-    string = ([[generalSwitches cellAtRow:SWITCH_COLORFUL column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[generalSwitches cellAtRow:SWITCH_COLORFUL column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroColorful"]] )
         [defaults setObject:string forKey:@"astroColorful"];
+    /* show degrees with minutes */
+    string = ([(NSCell*)[generalSwitches cellAtRow:SWITCH_DEGREESMINUTES column:0] state]) ? @"YES" : @"NO";
+    if ( ![string isEqual:[defaults objectForKey:@"astroDegreesMinutes"]] )
+        [defaults setObject:string forKey:@"astroDegreesMinutes"];
+    /* show fractal scale */
+    string = ([(NSCell*)[generalSwitches cellAtRow:SWITCH_FRACTALSCALE column:0] state]) ? @"YES" : @"NO";
+    if ( ![string isEqual:[defaults objectForKey:@"astroFractalScale"]] )
+        [defaults setObject:string forKey:@"astroFractalScale"];
 }
 
 /* set Objects defaults
@@ -286,39 +319,45 @@
     int         i;
 
     /* topocentric planet position */
-    string = ([[objectSwitches cellAtRow:SWITCH_TOPOCENTRIC column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[objectSwitches cellAtRow:SWITCH_TOPOCENTRIC column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroTopocentricPosition"]] )
         [defaults setObject:string forKey:@"astroTopocentricPosition"];
     /* heliocentric planet position */
-    string = ([[objectSwitches cellAtRow:SWITCH_HELIOCENTRIC column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[objectSwitches cellAtRow:SWITCH_HELIOCENTRIC column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroHeliocentricPosition"]] )
         [defaults setObject:string forKey:@"astroHeliocentricPosition"];
     /* equatorial planet position */
-    string = ([[objectSwitches cellAtRow:SWITCH_EQUATORIAL column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[objectSwitches cellAtRow:SWITCH_EQUATORIAL column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroEquatorialPosition"]] )
         [defaults setObject:string forKey:@"astroEquatorialPosition"];
     /* display mean nodes */
-    string = ([[objectSwitches cellAtRow:SWITCH_MEANNODES column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[objectSwitches cellAtRow:SWITCH_MEANNODES column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroMeanNodes"]] )
         [defaults setObject:string forKey:@"astroMeanNodes"];
 
     /* write names of active objects */
-    {   NSArray		*objects1, *objects2;
-        NSMutableArray	*objects = [NSMutableArray array], *nodes = [NSMutableArray array];
+    {   NSArray         *objects1, *objects2;
+        NSMutableArray  *objects = [NSMutableArray array],
+                        *nodes = [NSMutableArray array], *apsides = [NSMutableArray array];
 
         objects1 = OBJECTS_1;
         for (i=0; i<(int)[objects1 count]; i++)	// planets
-            if ([[object1Switches cellAtRow:i column:0] state])
+            if ([(NSCell*)[object1Switches cellAtRow:i column:0] state])
                 [objects addObject:[objects1 objectAtIndex:i]];
 
         for (i=0; i<(int)[objects1 count]; i++)	// nodes
-            if ([[nodeSwitches cellAtRow:i column:0] state])
+            if ([(NSCell*)[nodeSwitches cellAtRow:i column:0] state])
                 [nodes addObject:[objects1 objectAtIndex:i]];
         [defaults setObject:nodes forKey:@"astroNodes"];
 
+        for (i=0; i<(int)[objects1 count]; i++)	// perihelion
+            if ([(NSCell*)[periSwitches cellAtRow:i column:0] state])
+                [apsides addObject:[objects1 objectAtIndex:i]];
+        [defaults setObject:apsides forKey:@"astroPeri"];
+
         objects2 = OBJECTS_2;
         for (i=0; i<(int)[objects2 count]; i++)	// moon nodes, asteroids
-            if ([[object2Switches cellAtRow:i column:0] state])
+            if ([(NSCell*)[object2Switches cellAtRow:i column:0] state])
                 [objects addObject:[objects2 objectAtIndex:i]];
         [defaults setObject:objects forKey:@"astroObjects"];
     }
@@ -327,28 +366,28 @@
 /* set Chart defaults
  */
 - (void)setChart:sender
-{   NSString	*string;
-    NSColor	*color;
-    id		defaults = [NSUserDefaults standardUserDefaults];
+{   NSString        *string;
+    NSColor         *color;
+    NSUserDefaults  *defaults = [NSUserDefaults standardUserDefaults];
 
     /* show retrograde directions */
-    string = ([[chartSwitches cellAtRow:SWITCH_SHOWRETROGRADE column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[chartSwitches cellAtRow:SWITCH_SHOWRETROGRADE column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroShowRetrograde"]] )
         [defaults setObject:string forKey:@"astroShowRetrograde"];
     /* locale scale */
-    string = ([[chartSwitches cellAtRow:SWITCH_LOCALSCALE column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[chartSwitches cellAtRow:SWITCH_LOCALSCALE column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroLocalScale"]] )
         [defaults setObject:string forKey:@"astroLocalScale"];
     /* Declination */
-    string = ([[chartSwitches cellAtRow:SWITCH_SHOWDECLINATION column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[chartSwitches cellAtRow:SWITCH_SHOWDECLINATION column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroShowDeclination"]] )
         [defaults setObject:string forKey:@"astroShowDeclination"];
     /* Aspect Geometry */
-    string = ([[chartSwitches cellAtRow:SWITCH_SHOWASPECTGEO column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[chartSwitches cellAtRow:SWITCH_SHOWASPECTGEO column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroShowAspectGeo"]] )
         [defaults setObject:string forKey:@"astroShowAspectGeo"];
     /* AC fix */
-    string = ([[chartSwitches cellAtRow:SWITCH_ACFIX column:0] state]) ? @"YES" : @"NO";
+    string = ([(NSCell*)[chartSwitches cellAtRow:SWITCH_ACFIX column:0] state]) ? @"YES" : @"NO";
     if ( ![string isEqual:[defaults objectForKey:@"astroACFix"]] )
         [defaults setObject:string forKey:@"astroACFix"];
 
