@@ -1,11 +1,12 @@
 /* AstroChart.m
  * The circular Astrology chart
  *
- * Copyright (C) 1998-2014 by Georg Fleischmann
+ * Copyright (C) 1998-2015 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2012-08-16 (use [Document scale:scaleSize ...])
+ * modified: 2015-08-17 (perihelion added)
+ *           2012-08-16 (use [Document scale:scaleSize ...])
  *           2011-04-22 (modulo chart)
  *           2010-01-17 (-radix:...: scale chart to fit window)
  *           2009-04-01 (radix: no date: draw composite only)
@@ -53,7 +54,7 @@
 #define RADIUS_4	84.0/204.0	//0.35
 #define SCALE_MIN	((RADIUS_2-RADIUS_3) / 10.0)
 #define SCALE_MAX	(SCALE_MIN * 2.0)
-#define SYMBOL_SIZE	0.12
+#define SYMBOL_SIZE	0.12    // relative radius
 #define STAR_SIZE	0.25 //0.22
 #define FONT_SIZE	10.0	// absolute
 #define LINE_HEIGHT	11.0	// absolute
@@ -448,7 +449,7 @@ typedef enum
 }
 
 /* calculate main chart
- * modified: 2007-09-03
+ * modified: 2015-08-17
  */
 - (VGroup*)horoscopeWithCenter:(NSPoint)cp radius:(float)radius
                    tableOrigin:(NSPoint)tableOrigin
@@ -457,9 +458,9 @@ typedef enum
                            lat:(float)latitude lon:(float)longitude city:(NSString*)city
                           date:(NSCalendarDate*)date
 {   NSCalendarDate  *utc;
-    NSDictionary    *degreeDict, *nodeDict, *speedLonDict, *decDict, *speedDecDict;
+    NSDictionary    *degreeDict, *nodeDict, *periDict, *speedLonDict, *decDict, *speedDecDict;
     NSMutableArray  *planets = [NSMutableArray arrayWithObjects:@"AC", @"MC", nil];
-    NSArray         *nodes = Prefs_Nodes;
+    NSArray         *nodes = Prefs_Nodes, *peris = Prefs_Peri;
     NSPoint         p0, p1;
     NSRect          r;
     NSMutableString *mString = [NSMutableString string];
@@ -473,8 +474,8 @@ typedef enum
     NSFont          *systemFont10 = [NSFont systemFontOfSize:10.0];
     NSFont          *systemFont12 = [NSFont systemFontOfSize:12.0];
     NSFont          *systemFont20 = [NSFont systemFontOfSize:20.0];
-    NSFont          *nodeFont   = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE*0.8];
     NSFont          *planetFont = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE];
+    NSFont          *nodeFont   = [NSFont fontWithName:astroFont size:radius*SYMBOL_SIZE*0.8], *apsideFont = nodeFont;
     NSString        *dateFormat = [Prefs_DateFormat stringByAppendingFormat:@" %%H:%%M %%z"];
 
     [(utc = [[date copy] autorelease]) setTimeZone:[NSTimeZone timeZoneForSecondsFromGMT:0]];
@@ -486,6 +487,7 @@ typedef enum
     if (Prefs_ACFix)
         rotateAC = 180.0 - [degreeDict floatForKey:@"AC"];	// rotation of chart
     nodeDict     = [ephemeris currentNodeDict];
+    periDict     = [ephemeris currentPeriDict];
     speedLonDict = [ephemeris currentSpeedLonDict];
     decDict      = [ephemeris currentDeclinationDict];
     speedDecDict = [ephemeris currentSpeedDecDict];
@@ -544,7 +546,7 @@ typedef enum
                 angle = standardAngle(angle + rotateAC);
             angle = [self moduloAngle:angle forObject:node];
             p0 = NSMakePoint(cp.x + radius*RADIUS_2 - radius*(SCALE_MAX+SCALE_MIN), cp.y);
-            p1 = NSMakePoint(cp.x + radius*RADIUS_2 + radius*SCALE_MIN, cp.y);
+            p1 = NSMakePoint(cp.x + radius*RADIUS_2 + radius*SCALE_MIN,             cp.y);
             line = [VLine lineWithPoints:p0 :p1];
             [line setAngle:-angle withCenter:cp];
             [line setColor:[NSColor darkGrayColor]];
@@ -552,7 +554,27 @@ typedef enum
 
             [group addObject:[VText text:planetSymbol(node) // nodeSymbols(node)
                                   center:NSMakePoint(p0.x-(radius*SYMBOL_SIZE*1.2), cp.y)
-                                   color:[NSColor grayColor] angle:angle center:cp font:nodeFont]];
+                                   color:[NSColor darkGrayColor] angle:angle center:cp font:nodeFont]];
+        }
+
+        /* apsides (perihelion, aphelion) */
+        for ( i=0; i<(int)[peris count]; i++ )
+        {   NSString	*peri = [peris objectAtIndex:i];
+            VFloat		angle = [periDict floatForKey:peri];
+
+            if (rotateAC)
+                angle = standardAngle(angle + rotateAC);
+            angle = [self moduloAngle:angle forObject:peri];
+            p0 = NSMakePoint(cp.x + radius*RADIUS_2 - radius*(SCALE_MAX+SCALE_MIN), cp.y);
+            p1 = NSMakePoint(cp.x + radius*RADIUS_2 + radius*SCALE_MIN,             cp.y);
+            line = [VLine lineWithPoints:p0 :p1];
+            [line setAngle:-angle withCenter:cp];
+            [line setColor:[NSColor darkGrayColor]];
+            [group addObject:line];
+
+            [group addObject:[VText text:planetSymbol(peri) // periSymbols(peri)
+                                  center:NSMakePoint(p0.x-(radius*SYMBOL_SIZE*2.0), cp.y)
+                                   color:[NSColor grayColor] angle:angle center:cp font:apsideFont]];
         }
 
         /* planets */
@@ -682,9 +704,9 @@ typedef enum
         NSArray	*houseColors = colorWheel(1.0);
 
         for ( i=1; i<=houseCnt; i++ )
-        {   double	a = house[i];
-            float	radCenter = radius*RADIUS_4;
-            NSString	*string;
+        {   double      a = house[i];
+            float       radCenter = radius*RADIUS_4;
+            NSString    *string;
 
             if (rotateAC)
                 a = standardAngle(a + rotateAC);
@@ -763,8 +785,8 @@ typedef enum
      */
     if ( DiffPoint(tableOrigin, NSZeroPoint) > 0.0 )	// aspect symbols
     {   VGroup		*subGroup = [VGroup group];
-        float		x = tableOrigin.x, y = tableOrigin.y, w, h;
-        float		orb = 6.0, cellSize = LINE_HEIGHT + 2.0;
+        VFloat		x = tableOrigin.x, y = tableOrigin.y, w, h;
+        VFloat		orb = 6.0, cellSize = LINE_HEIGHT + 2.0;
         NSFont		*symbolFont = [NSFont fontWithName:astroFont size:FONT_SIZE];
         //VRectangle	*rectangle;
 
@@ -779,8 +801,9 @@ typedef enum
             r = [text bounds];
 #ifdef __APPLE__
             if (r.size.height > cnt * cellSize + 2)	// workaround Apple -> reduce lineHeight
-            {   text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
-                           center:cp lineHeight:cellSize-1 font:symbolFont];
+             {  VFloat  lineHeight = cellSize - (r.size.height / cnt - cellSize);
+                text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
+                           center:cp lineHeight:lineHeight font:symbolFont];
                 r = [text bounds];
             }
 #endif
@@ -800,15 +823,18 @@ typedef enum
                                                                 (i<cnt-1) ? @"\n" : @""];
                 [mString appendString:string];
             }
+
             text = [VText text:mString origin:NSMakePoint(x /*+ cellSize*/ + 3.0, y) color:color angle:0.0
                        center:cp lineHeight:cellSize align:NSLeftTextAlignment
                          font:[NSFont userFixedPitchFontOfSize:FONT_SIZE]];
             r = [text bounds];
 #ifdef __APPLE__
             if (r.size.height > cnt * cellSize + 2)	// workaround Apple -> reduce lineHeight
+            {   VFloat  lineHeight = cellSize - (r.size.height / cnt - cellSize);
                 text = [VText text:mString origin:NSMakePoint(x /*+ cellSize*/ + 3.0, y) color:color angle:0.0
-                           center:cp lineHeight:cellSize-1 align:NSLeftTextAlignment
-                             font:[NSFont userFixedPitchFontOfSize:FONT_SIZE]];
+                            center:cp lineHeight:lineHeight align:NSLeftTextAlignment
+                              font:[NSFont userFixedPitchFontOfSize:FONT_SIZE]];
+            }
 #endif
             [subGroup addObject:text];
             w = [text bounds].origin.x - x + [text bounds].size.width + 3.0;
@@ -841,13 +867,15 @@ typedef enum
         [mString setString:@""];
         for ( i=0, cnt=(int)[planets count]; i<cnt; i++ )
             [mString appendFormat:@"%@%@", planetSymbol([planets objectAtIndex:i]), (i<cnt-1) ? @"\n" : @""];
+        // TODO: add individual text objects to avoid line height issues
         text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
                    center:cp lineHeight:cellSize font:symbolFont];
         r = [text bounds];
-#ifdef __APPLE__
+#ifdef __APPLE__    // <= Mac OS X 10.8 => cellSize-1 or -2, >= Mac OS 10.10 => cellSize-2
         if (r.size.height > cnt * cellSize + 2)	// workaround Apple -> reduce lineHeight
-        {   text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
-                       center:cp lineHeight:cellSize-1 font:symbolFont];
+        {   VFloat  lineHeight = cellSize - (r.size.height / cnt - cellSize);
+            text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
+                        center:cp lineHeight:lineHeight font:symbolFont];
             r = [text bounds];
         }
 #endif
@@ -1288,9 +1316,11 @@ typedef enum
             r = [text bounds];
 #ifdef __APPLE__
             if (r.size.height > cnt * cellSize + 2)	// workaround Apple -> reduce lineHeight
+            {   VFloat  lineHeight = cellSize - (r.size.height / cnt - cellSize);
                 text = [VText text:mString origin:NSMakePoint(x + 3.0, y) color:color angle:0.0
-                           center:cp lineHeight:cellSize-1 align:NSLeftTextAlignment
+                           center:cp lineHeight:lineHeight align:NSLeftTextAlignment
                              font:[NSFont userFixedPitchFontOfSize:FONT_SIZE]];
+            }
 #endif
             /* correct x to lower left of table */
             if (showCombiAspects)	// show aspect table
@@ -1340,8 +1370,9 @@ typedef enum
             r = [text bounds];
 #ifdef __APPLE__
             if (r.size.height > cnt * cellSize + 2)	// workaround Apple -> reduce lineHeight
-            {   text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
-                           center:cp lineHeight:cellSize-1 font:symbolFont];
+            {   VFloat  lineHeight = cellSize - (r.size.height / cnt - cellSize);
+                text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
+                           center:cp lineHeight:lineHeight font:symbolFont];
                 r = [text bounds];
             }
 #endif
@@ -1375,8 +1406,9 @@ typedef enum
             r = [text bounds];
 #ifdef __APPLE__
             if (r.size.height > cnt * cellSize + 2)	// workaround Apple -> reduce lineHeight
-            {   text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
-                           center:cp lineHeight:cellSize-1 font:symbolFont];
+            {   VFloat  lineHeight = cellSize - (r.size.height / cnt - cellSize);
+                text = [VText text:mString base:NSMakePoint(x, y) color:color angle:0.0
+                           center:cp lineHeight:lineHeight font:symbolFont];
                 r = [text bounds];
             }
 #endif
@@ -1808,7 +1840,7 @@ typedef enum
     for (i=0; i<maxInterval; i++)
         if ( DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0)
         {
-            if ( DiffPoint(chartTemplate.startI[i],  NSZeroPoint) > 0.0 )
+            if ( DiffPoint(chartTemplate.startI[i], NSZeroPoint) > 0.0 )
                 chartTemplate.radiusI[i] = sqrt( SqrDistPoints(chartTemplate.centerI[i], chartTemplate.startI[i]) );
         }
 
@@ -1922,7 +1954,7 @@ typedef enum
     [astroFont release];
     astroFont = [Prefs_AstroFont retain];
     if (![astroFont length])
-        astroFont = @"vhfAstro";
+        astroFont = @"CenonAstro";  //astroFont = @"vhfAstro";
 /*#ifdef GNUSTEP_BASE_LIBRARY	// Workaround: GNUstep (X-Backend) makes the first char of the name capital
     if (![NSFont fontWithName:astroFont size:12.0])
         astroFont = [[[[Prefs_AstroFont substringToIndex:1] uppercaseString]
@@ -1954,7 +1986,8 @@ typedef enum
                                                symbolSize:radius*SYMBOL_SIZE rotate:rotateAC]];
 
             /* scale */
-            if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
+            if ( ! Prefs_FractalScale
+                 && (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
                  && chartTemplate.components & CHART_SCALE )
                 [layer addObject:[self scaleWithCenter:cp radius:radius
                                             scaleSize1:radius*SCALE_MIN scaleSize2:radius*SCALE_MAX
@@ -2010,10 +2043,10 @@ typedef enum
         /* Create Interval Chart
          */
         if ( DiffPoint(chartTemplate.centerI[0], NSZeroPoint) > 0.0 )
-        {   int		i;
-            int		min = Prefs_AstroInterval, minMinutes = 999999;
-            NSString	*strFormat;
-            VText		*text;
+        {   int         i;
+            int         min = Prefs_AstroInterval, minMinutes = 999999;
+            NSString    *strFormat;
+            VText       *text;
 
             /* find min interval = base interval */
             if (min != 0)
