@@ -1,36 +1,36 @@
 /* APBasicLevel.h
  *
- * Copyright 1996-2005 by vhf interservice GmbH
+ * Copyright 1996-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1996-03-03
  * Modified: 2003-03-29
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_APBASICLEVEL
-#define VHF_H_APBASICLEVEL
+#ifndef CEN_H_APBASICLEVEL
+#define CEN_H_APBASICLEVEL
 
 #include <AppKit/AppKit.h>
 
-@interface APBasicLevel:NSPanel
+@interface APBasicLevel:NSPanel <NSWindowDelegate>
 {
     id	window;		// Astro Panel
 }
@@ -48,4 +48,4 @@
 
 @end
 
-#endif	// VHF_H_APBASICLEVEL
+#endif	// CEN_H_APBASICLEVEL
