@@ -1,32 +1,32 @@
 /* APChart.m
  *
- * Copyright (C) 2001-2007 by vhf interservice GmbH
+ * Copyright (C) 2001-2007 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  2001-05-18
  * Modified: 2007-09-03
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
-#ifndef VHF_H_APCHART
-#define VHF_H_APCHART
+#ifndef CEN_H_APCHART
+#define CEN_H_APCHART
 
 #include <AppKit/AppKit.h>
 #include "APBasicLevel.h"
@@ -81,4 +81,4 @@
 
 @end
 
-#endif	// VHF_H_APCHART
+#endif	// CEN_H_APCHART
