@@ -1,29 +1,29 @@
 /* APMap.m
  * Controls the generation of maps
  *
- * Copyright (C) 2001-2007 by vhf interservice GmbH
+ * Copyright (C) 2001-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  2001-05-18
  * Modified: 2007-09-03
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include <VHFShared/vhfCommonFunctions.h>
@@ -104,7 +104,7 @@
         if ( i < 0 )
         {   NSFileManager	*fileManager = [NSFileManager defaultManager];
             NSString		*path = nil, *relPath;
-            NSString		*file = [MAP_FILE stringByAppendingPathExtension: DOCUMENT_EXT];
+            NSString		*file = [MAP_FILENAME stringByAppendingPathExtension: DOCUMENT_EXT];
 
             relPath = vhfPathWithPathComponents(@"Astro", @"Maps", file, nil);
             for (i=0; i<3; i++)
@@ -299,21 +299,21 @@ printf("Schraege: %.2f\n", dia);
 #endif
 
 - (void)loadMap
-{   NSString	*path = [NSString stringWithFormat:@"%@/%@/%@", userLibrary(), MODULENAME, MAP_INFOFILE];
-    int		i, cnt;
-    NSArray	*keys;
+{   NSString    *path = [NSString stringWithFormat:@"%@/%@/%@", userLibrary(), MODULENAME, MAP_INFOFILE];
+    int         i, cnt;
+    NSArray     *keys;
 
     [mapDict release];
-    mapDict = [[NSDictionary dictionaryWithContentsOfFile:path] retain];
+    mapDict = [[NSMutableDictionary dictionaryWithContentsOfFile:path] retain];
     if ( !mapDict )
     {   NSMutableDictionary	*dict = [NSMutableDictionary dictionary];
 
-	//NSRunAlertPanel(@"", CANTLOADFILE_STRING, OK_STRING, nil, nil, path);
+        //NSRunAlertPanel(@"", CANTLOADFILE_STRING, OK_STRING, nil, nil, path);
         [dict setObject: @"11.0" forKey:@"centerLng"];
         [dict setObject:  @"0.0" forKey:@"centerLat"];
         [dict setObject:@"360.0" forKey:@"widthLng"];
         [dict setObject:@"180.0" forKey:@"widthLat"];
-        mapDict = [[NSDictionary dictionaryWithObject:dict forKey:@"World"] retain];
+        mapDict = [[NSMutableDictionary dictionaryWithObject:dict forKey:@"World"] retain];
     }
 
     keys = [mapDict allKeys];
