@@ -1,11 +1,11 @@
 /* AstroPrincipal.m
  * Commander of the Astrology module
  *
- * Copyright (C) 2003-2014 by Georg Fleischmann
+ * Copyright (C) 2003-2015 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2014-11-20
+ * modified: 2015-08-04 (+initialize: astroFont = CenonAstro)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the Cenon Public License as
@@ -52,7 +52,8 @@
 
 /*
  * created:  1999-03-15
- * modified: 2006-04-27 (call registration in preferences module)
+ * modified: 2015-08-04 (astroFont = CenonAstro)
+ *           2006-04-27 (call registration in preferences module)
  * register the defaults
  */
 + (void)initialize
@@ -64,8 +65,8 @@
     [registrationDict setObject:vhfStringFromRGBColor([NSColor whiteColor]) forKey:@"astroBGColor"];
     [registrationDict setObject:@"YES" forKey:@"astroShowPanel"];
     [registrationDict setObject:@"YES" forKey:@"astroShowRetrograde"];
-    [registrationDict setObject:@"%d.%m.%Y" forKey:@"astroDateFormat"];
-    [registrationDict setObject:@"vhfAstro" forKey:@"astroFont"];
+    [registrationDict setObject:@"%d.%m.%Y"     forKey:@"astroDateFormat"];
+    [registrationDict setObject:@"CenonAstro"   forKey:@"astroFont"];
     //[registrationDict setObject:@"YES" forKey:@"astroShowHouseSize"];
     //[registrationDict setObject:@"YES" forKey:@"astroShowHouseMaxima"];
     [registrationDict setObject:@"YES" forKey:@"astroTopocentricPosition"];
@@ -464,9 +465,10 @@ NSString *stringFromDeg(float deg)
             if ( [[doc name] hasPrefix:CHART_PREFIX] )
                 break;
         }
-        if ( i < 0 )
-        {   NSLog(@"AstroPrincipal: No document found with prefix '%@' to display data!", CHART_PREFIX);
-            return;
+        if ( i < 0 )    // no astro chart open
+        {   [[astroPanel windowAt:AP_CHART] set:nil];   // open astro chart
+            //NSLog(@"AstroPrincipal: No document found with prefix '%@' to display data!", CHART_PREFIX);
+            //return;
         }
 
         astroChart = [[astroPanel windowAt:AP_CHART] astroChart];
