@@ -1,7 +1,7 @@
 /* EventManager.m
  * controller class and files owner of the EventPanel
  *
- * Copyright (C) 2003-2010 by vhf interservice GmbH
+ * Copyright (C) 2003-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  2003-06-22
@@ -10,26 +10,27 @@
  *           2006-01-15 (date formats)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@cenon.de
+ * http://www.cenon.info
  */
 
 #include "EventManager.h"
 #include "../Cenon/VHFShared/VHFDictionaryAdditions.h"
+#include "../Cenon/VHFShared/VHFSystemAdditions.h"      // NSFileManagerAdditions
 #include "../Cenon/App.h"
 #include "../Cenon/functions.h"
 #include "../Cenon/messages.h"
@@ -329,14 +330,14 @@ static int indexFromType(NSString *typeString)
     [eventBrowser selectRow:[eventBrowser selectedRowInColumn:0] inColumn:0];
 }
 - (void)modify:sender
-{   int			folderIx = [eventBrowser selectedRowInColumn:0];
-    int			eventIx  = [eventBrowser selectedRowInColumn:1], i;
-    NSMutableArray	*events;
-    NSMutableDictionary	*event;
-    NSString		*dateFormat = astroDateFormatForString([dateField stringValue]);
-    NSString		*dateFormat_Z = [dateFormat stringByAppendingString:@" %H:%M %Z"];
-    NSString		*dateFormat_z = [dateFormat stringByAppendingString:@" %H:%M %z"];
-    NSString		*string;
+{   int                 folderIx = [eventBrowser selectedRowInColumn:0];
+    int                 eventIx  = [eventBrowser selectedRowInColumn:1], i;
+    NSMutableArray      *events;
+    NSMutableDictionary *event;
+    NSString            *dateFormat = astroDateFormatForString([dateField stringValue]);
+    NSString            *dateFormat_Z = [dateFormat stringByAppendingString:@" %H:%M %Z"];
+    NSString            *dateFormat_z = [dateFormat stringByAppendingString:@" %H:%M %z"];
+    NSString            *string;
 
     if (eventIx < 0)
         return;
@@ -368,7 +369,7 @@ static int indexFromType(NSString *typeString)
     if ( ![[eventField stringValue] length] )
         return;
     if ([events containsObject:[eventField stringValue]])
-    {   NSLog(@"Modify: Event already in database!", [eventField stringValue]);
+    {   NSLog(@"Modify: Event (%@) already in database!", [eventField stringValue]);
         return;
     }
 
@@ -608,13 +609,13 @@ static int indexFromType(NSString *typeString)
  */
 
 /* load events from file
- * modified: 2005-07-24
+ * modified: 2014-11-20
  */
 - (void)loadEvents
-{   NSString		*path;
-    NSArray		*array;
-    NSFileManager	*fileManager = [NSFileManager defaultManager];
-    int			i, j;
+{   NSString        *path;
+    NSArray         *array;
+    NSFileManager   *fileManager = [NSFileManager defaultManager];
+    int             i, j;
 
     [eventBrowser setDelegate:self];
     [eventBrowser setTarget:self];
@@ -636,7 +637,7 @@ static int indexFromType(NSString *typeString)
             path = vhfPathWithPathComponents(localLibrary(), MODULENAME, @"Data", nil);
         else
             path = vhfPathWithPathComponents(userLibrary(), MODULENAME, @"Data", nil);
-        array = [fileManager directoryContentsAtPath:path];
+        array = [fileManager contentsOfDirectoryAtPath:path];
         for (j=0; j<(int)[array count]; j++)
         {   NSString	*file     = [array objectAtIndex:j];
             NSString	*filePath = [path stringByAppendingPathComponent:file];
