@@ -183,10 +183,10 @@ typedef struct
 - (double)julianDayForYear:(int)year month:(int)month day:(int)day
                       hour:(int)hour minute:(int)minute second:(int)second bc:(BOOL)bcFlag;
 
-/* NSCalendarDate methods */
-- (EphObject*)objectsAtUTC:(NSCalendarDate*)utc;
+/* NSDate / NSCalendarDate methods */
+- (EphObject*)objectsAtUTC:(NSDate*)utc;
 - (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(float)lat  lon:(float)lon;
-- (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
+- (EphObject*)objectsAtUTC:(NSDate*)utc lat:(double)lat lon:(double)lon
                       elev:(double)alt topocentric:(BOOL)topocentric
               heliocentric:(BOOL)heliocentric
                 equatorial:(BOOL)equatorial;
@@ -223,6 +223,7 @@ typedef struct
 - (NSMutableDictionary*)currentObjectDict;
 - (NSMutableDictionary*)currentSpeedLonDict;	// V lon
 - (NSMutableDictionary*)currentNodeDict;
+- (NSMutableDictionary*)currentPeriDict;        // Perihelion
 - (NSMutableDictionary*)currentDeclinationDict;	// dec
 - (NSMutableDictionary*)currentSpeedDecDict;	// V dec
 
