@@ -5,7 +5,8 @@
  * Author:   Georg Fleischmann
  *
  * created:  2001-09-02
- * modified: 2015-01-26 (equatorial)
+ * modified: 2015-05-14 (-objectsAtUTC:nsDate works with NSDate and NSCalendarDate)
+ *           2015-01-26 (equatorial)
  *           2014-11-21 (calcHelio, heliocentric added)
  *           2014-01-04 (clean up)
  *           2011-04-24 (-objectSymbols)
@@ -136,40 +137,101 @@ static NSArray *objectSymbols = nil;
 
     return objs;
 }
-- (EphObject*)objectsAtUTC:(NSCalendarDate*)utc lat:(double)lat lon:(double)lon
+- (EphObject*)objectsAtUTC:(NSDate*)utc lat:(double)lat lon:(double)lon
                       elev:(double)alt topocentric:(BOOL)topocentric
               heliocentric:(BOOL)heliocentric
                 equatorial:(BOOL)equatorial
-{   NSCalendarDate	*st = sideralTime(utc, lon);
-    EphObject		*objs;
+{   //NSCalendarDate	*st = sideralTime(utc, lon);
+    double      jd, st;
+    int         y, m, d, H, M, S;
+    EphObject   *objs;
 
-    if (!topocentric)
-        lon = -360.0;
-    objs = [self objectsAtYear:[utc yearOfCommonEra]  month:[utc monthOfYear]     day:[utc dayOfMonth]
-                          hour:[utc hourOfDay]       minute:[utc minuteOfHour] second:[utc secondOfMinute]
+    if ( [utc isKindOfClass:[NSCalendarDate class]] )
+    {   NSCalendarDate  *calDate = (NSCalendarDate*)utc;
+
+        //[calDate setTimeZone:timeZone /*[NSTimeZone timeZoneForSecondsFromGMT:0]*/];
+        y = [calDate yearOfCommonEra];
+        m = [calDate monthOfYear];
+        d = [calDate dayOfMonth];
+        H = [calDate hourOfDay];
+        M = [calDate minuteOfHour];
+        S = [calDate secondOfMinute];
+    }
+    else
+    {   NSCalendar          *calendar = [[NSCalendar alloc] initWithCalendarIdentifier:NSGregorianCalendar];
+        unsigned            unitFlags = NSYearCalendarUnit | NSMonthCalendarUnit |  NSDayCalendarUnit |
+        NSHourCalendarUnit | NSMinuteCalendarUnit;
+        NSDateComponents    *dateParts;
+        NSTimeZone          *timeZone = [NSTimeZone timeZoneForSecondsFromGMT:0];
+
+        [calendar setTimeZone:timeZone];
+        dateParts = [calendar components:unitFlags fromDate:utc];
+        y = [dateParts year];
+        m = [dateParts month];
+        d = [dateParts day];
+        H = [dateParts hour];
+        M = [dateParts minute];
+        S = [dateParts second];
+        [calendar release];
+    }
+    jd = cenJD(y, m, d, H, M, S);   // julian day (reference -4712)
+    st = vhfSideralTime(jd, lon);
+
+    //if (!topocentric)
+    //    lon = -360.0;
+    objs = [self objectsAtYear:y month:m day:d hour:H minute:M second:S
                      longitude:lon latitude:lat elevation:alt
                    topocentric:topocentric /*truePos:NO */
                   heliocentric:heliocentric equatorial:equatorial];
 
     /* add ac, mc */
-    objs[O_AC].lon = ac(st, lat);
+    objs[O_AC].lon = vhfAC(st, lat);    //ac(st, lat);
     objs[O_AC].vLon = 1.0;
     objs[O_AC].vLat = 0.0;
-    objs[O_MC].lon = mc(st);
+    objs[O_MC].lon = vhfMC(st);         //mc(st);
     objs[O_MC].vLon = 1.0;
     objs[O_MC].vLat = 0.0;
 
     return objs;
 }
 
-- (EphObject*)objectsAtUTC:(NSCalendarDate*)utc
-{
+- (EphObject*)objectsAtUTC:(NSDate*)utc
+{   int         y, m, d, H, M, S;
+    NSTimeZone  *timeZone = [NSTimeZone timeZoneForSecondsFromGMT:0];
+
     /* we have day, month and year and convert to Julian day number */
     //h = (double)[utc hourOfDay] + ((double)[utc minuteOfHour]*60.0 + (double)[utc secondOfMinute]) / 3600.0;
     //tjd = swe_julday([utc yearOfCommonEra], [utc monthOfYear], [utc dayOfMonth], h, SE_GREG_CAL);
 
-    return [self objectsAtYear:[utc yearOfCommonEra]  month:[utc monthOfYear]     day:[utc dayOfMonth]
-                          hour:[utc hourOfDay]       minute:[utc minuteOfHour] second:[utc secondOfMinute]
+    if ( [utc isKindOfClass:[NSCalendarDate class]] )
+    {   NSCalendarDate  *calDate = (NSCalendarDate*)utc;
+
+        //[calDate setTimeZone:timeZone /*[NSTimeZone timeZoneForSecondsFromGMT:0]*/];
+        y = [calDate yearOfCommonEra];
+        m = [calDate monthOfYear];
+        d = [calDate dayOfMonth];
+        H = [calDate hourOfDay];
+        M = [calDate minuteOfHour];
+        S = [calDate secondOfMinute];
+    }
+    else
+    {   NSCalendar          *calendar = [[NSCalendar alloc] initWithCalendarIdentifier:NSGregorianCalendar];
+        unsigned            unitFlags = NSYearCalendarUnit | NSMonthCalendarUnit |  NSDayCalendarUnit |
+                            NSHourCalendarUnit | NSMinuteCalendarUnit;
+        NSDateComponents    *dateParts;
+
+        [calendar setTimeZone:timeZone];
+        dateParts = [calendar components:unitFlags fromDate:utc];
+        y = [dateParts year];
+        m = [dateParts month];
+        d = [dateParts day];
+        H = [dateParts hour];
+        M = [dateParts minute];
+        S = [dateParts second];
+        [calendar release];
+    }
+
+    return [self objectsAtYear:y month:m day:d hour:H minute:M second:S
                      longitude:-360.0 latitude:-360.0 elevation:0.0
                    topocentric:NO /*truePos:NO */
                   heliocentric:NO equatorial:NO];
@@ -218,12 +280,12 @@ static NSArray *objectSymbols = nil;
     // TODO: SEFLG_TRUEPOS adds the true position of planet (opposed to visible position in sky)
     /* heliocentric positions (instead of geocentric / apparent) */
     if ( helioCen )
-        helioFlag = SEFLG_HELCTR;
+        helioFlag = SEFLG_HELCTR | SEFLG_TRUEPOS; // true position versus apparent position (speed of light)
 
     /* a loop over all planets */
     for (p = SE_SUN; p <= SE_VESTA; p++)
     {
-        if (p == SE_EARTH)
+        if ( !helioFlag && p == SE_EARTH )
             continue;
 
         /* do the coordinate calculation for this planet p
@@ -234,13 +296,14 @@ static NSArray *objectSymbols = nil;
          * x[4] = speed in latitude (deg/day), negative = retrograde
          * x[5] = speed in distance (AU/day)
          */
-        iflag = SEFLG_SPEED;
+        iflag = SEFLG_SPEED;    // | SEFLG_TRUEPOS; // true position versus apparent position (speed of light)
         if ( equatorial )
             iflag |= SEFLG_EQUATORIAL;  // (heliocentric) equatorial coordinates
         if ( helioFlag                  // Moon, Sun, Moon-Nodes/Apogee stay geo- or topocentric
-             && (   p != SE_MOON      && p != SE_SUN
-                 && p != SE_MEAN_NODE && p != SE_TRUE_NODE && p != SE_MEAN_APOG && p != SE_OSCU_APOG) )
-            iflag |= helioFlag | SEFLG_NOGDEFL | SEFLG_NOABERR;
+             && (   p != SE_MOON      && p != SE_SUN    // heliocentric Moon == Earth
+                 && p != SE_MEAN_NODE && p != SE_TRUE_NODE && p != SE_MEAN_APOG && p != SE_OSCU_APOG) )   // all = 0.0
+            iflag |= helioFlag | SEFLG_NOGDEFL | SEFLG_NOABERR; // no gravitational deflection, no annual aberration of light
+            //iflag |= helioFlag;
         else                            // helio has priority for planets (but not Moon and Sun)
             iflag |= topoFlag;
         if ((iflgret = swe_calc_ut(tjd, p, iflag, x2, serr)) < 0)
@@ -469,7 +532,7 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
         if ( helioFlag                  // Moon, Sun, Moon-Nodes/Apogee stay geo- or topocentric
             && (   p != SE_MOON      && p != SE_SUN
                 && p != SE_MEAN_NODE && p != SE_TRUE_NODE && p != SE_MEAN_APOG && p != SE_OSCU_APOG) )
-            iflag |= SEFLG_HELCTR | SEFLG_NOGDEFL | SEFLG_NOABERR;
+            iflag |= SEFLG_HELCTR | SEFLG_NOGDEFL | SEFLG_NOABERR | SEFLG_TRUEPOS;
         else if (topoFlag)              // helio has priority for planets (but not Moon and Sun)
             iflag |= SEFLG_TOPOCTR;
 
@@ -525,7 +588,7 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
             if (p >= SE_MEAN_NODE && p <= SE_OSCU_APOG)	// skip Moon node/apogee
                 continue;
 
-            iflag = SEFLG_SPEED /*| ((topoFlag) ? SEFLG_TOPOCTR : 0)*/ | ((helioFlag) ? SEFLG_HELCTR : 0);
+            iflag = SEFLG_SPEED /*| ((topoFlag) ? SEFLG_TOPOCTR : 0)*/ | ((helioFlag) ? SEFLG_HELCTR | SEFLG_TRUEPOS : 0);
             if ( equatorialFlag )
                 iflag |= SEFLG_EQUATORIAL;  // (heliocentric) equatorial coordinates
 
@@ -622,7 +685,7 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 
     /* sun node */
     if (ephFlags & EPHFLAG_NOD)
-    {   int	year, m, d;
+    {   int     year, m, d;
         double	hour;
 
         swe_revjul (tjd, 1, &year, &m, &d, &hour);
@@ -771,19 +834,30 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 /* get nodes from current objects
  */
 - (NSMutableDictionary*)currentNodeDict
-{   NSMutableDictionary		*degreeDict = [NSMutableDictionary dictionary];
-    int				p;
+{   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
+    int                 p;
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [degreeDict setObject:[NSNumber numberWithDouble:objects[p].nodeLon]
                        forKey:[objectNames objectAtIndex:p]];
     return degreeDict;
 }
+/* get perihelions from current objects
+ */
+- (NSMutableDictionary*)currentPeriDict
+{   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
+    int                 p;
+
+    for (p = SE_SUN; p <= SE_VESTA; p++)
+        [degreeDict setObject:[NSNumber numberWithDouble:objects[p].perihelionLon]
+                       forKey:[objectNames objectAtIndex:p]];
+    return degreeDict;
+}
 /* get declination from current objects
  */
 - (NSMutableDictionary*)currentDeclinationDict
-{   NSMutableDictionary		*degreeDict = [NSMutableDictionary dictionary];
-    int				p;
+{   NSMutableDictionary *degreeDict = [NSMutableDictionary dictionary];
+    int                 p;
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [degreeDict setObject:[NSNumber numberWithDouble:objects[p].dec]
@@ -793,8 +867,8 @@ printf("st = %f = %f\n", vhfSideralTime(tjd, 9.48), hour);*/
 /* get declination speed from current objects
  */
 - (NSMutableDictionary*)currentSpeedDecDict
-{   NSMutableDictionary		*speedDict = [NSMutableDictionary dictionary];
-    int				p;
+{   NSMutableDictionary *speedDict = [NSMutableDictionary dictionary];
+    int                 p;
 
     for (p = SE_SUN; p <= SE_VESTA; p++)
         [speedDict setObject:[NSNumber numberWithDouble:objects[p].vDec]
