@@ -1,7 +1,7 @@
 /* VTextAstroAdditions.m
  * convenient text methods
  *
- * Copyright (C) 1999-2006 by Cenon GmbH
+ * Copyright (C) 1999-2015 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1999-06-11
@@ -34,13 +34,13 @@
 
 /* text with box origin (not base!) at given position (p)
  */
-+ (VText*)text:(NSString*)string		// the string
-        origin:(NSPoint)p			// origin of text box
-         color:(NSColor*)col			// text color
-         angle:(float)angle center:(NSPoint)cp	// rotation angle + center
-    lineHeight:(float)lineHeight		// line height
-         align:(NSTextAlignment)mode		// alignment
-          font:(NSFont*)fnt			// font
++ (VText*)text:(NSString*)string                // the string
+        origin:(NSPoint)p                       // origin of text box (unrotated)
+         color:(NSColor*)col                    // text color
+         angle:(float)angle center:(NSPoint)cp  // rotation angle + center
+    lineHeight:(float)lineHeight                // line height
+         align:(NSTextAlignment)mode            // alignment
+          font:(NSFont*)fnt                     // font
 {   VText	*text = [VText textGraphic];
     NSRect	r;
 
@@ -64,13 +64,13 @@
 
 
 /* text (all parameters) */
-+ (VText*)text:(NSString*)string		// string
-          base:(NSPoint)p			// base line position
-         color:(NSColor*)col			// text color
++ (VText*)text:(NSString*)string                // string
+          base:(NSPoint)p                       // base line position
+         color:(NSColor*)col                    // text color
          angle:(float)angle center:(NSPoint)cp	// rotation angle and center
-    lineHeight:(float)lineHeight		// line height
-         align:(NSTextAlignment)mode		// alignment
-          font:(NSFont*)fnt			// font
+    lineHeight:(float)lineHeight                // line height
+         align:(NSTextAlignment)mode            // alignment
+          font:(NSFont*)fnt                     // font
 {   VText	*text = [VText textGraphic];
     NSRect	r;
 
@@ -90,11 +90,11 @@
 }
 
 /* text (default line height) */
-+ (VText*)text:(NSString*)string		// string
-          base:(NSPoint)p			// base line position
-         color:(NSColor*)col			// text color
-         angle:(float)angle center:(NSPoint)cp	// rotation angle and center
-         align:(NSTextAlignment)mode		// text alignment
++ (VText*)text:(NSString*)string                // string
+          base:(NSPoint)p                       // base line position
+         color:(NSColor*)col                    // text color
+         angle:(float)angle center:(NSPoint)cp  // rotation angle and center
+         align:(NSTextAlignment)mode            // text alignment
           font:(NSFont*)fnt
 {
     return [VText text:string base:p color:col
@@ -104,10 +104,10 @@
 
 /* text (left aligned) */
 + (VText*)text:(NSString*)string
-          base:(NSPoint)p			// base line position of text
+          base:(NSPoint)p                       // base line position of text
          color:(NSColor*)col
          angle:(float)angle center:(NSPoint)cp
-    lineHeight:(float)lineHeight		// line height
+    lineHeight:(float)lineHeight                // line height
           font:(NSFont*)fnt
 {
     return [VText text:string base:p color:col
@@ -129,12 +129,12 @@
 
 
 /* centered text */
-+ (VText*)text:(NSString*)string		// string
-        center:(NSPoint)p			// center position of text box
-         color:(NSColor*)col			// text color
-         angle:(float)angle center:(NSPoint)cp	// rotation angle and center
-    lineHeight:(float)lineHeight		// line height
-          font:(NSFont*)fnt			// font
++ (VText*)text:(NSString*)string        // string
+        center:(NSPoint)p               // center position of text box
+         color:(NSColor*)col            // text color
+         angle:(float)angle center:(NSPoint)cp  // rotation angle and center
+    lineHeight:(float)lineHeight        // line height
+          font:(NSFont*)fnt             // font
 {   VText	*text = [VText textGraphic];
     NSRect	r;
 
@@ -161,9 +161,9 @@
 
 /* centered text (default line height) */
 + (VText*)text:(NSString*)string
-        center:(NSPoint)p			// center of text box
+        center:(NSPoint)p                       // center of text box
          color:(NSColor*)col
-         angle:(float)angle center:(NSPoint)cp	// rotation angle and center
+         angle:(float)angle center:(NSPoint)cp  // rotation angle and center
           font:(NSFont*)fnt
 {
     return [VText text:string center:p color:col
@@ -188,11 +188,11 @@
 }
 
 /* centered rotated text */
-+ (VText*)text:(NSString*)string		// string
-        center:(NSPoint)p			// center position of text box
-         color:(NSColor*)col			// text color
-      rotAngle:(float)angle center:(NSPoint)cp	// rotation angle and center - text itself is rotated
-          font:(NSFont*)fnt			// font
++ (VText*)text:(NSString*)string                // string
+        center:(NSPoint)p                       // center position of text box
+         color:(NSColor*)col                    // text color
+      rotAngle:(float)angle center:(NSPoint)cp  // rotation angle and center - text itself is rotated
+          font:(NSFont*)fnt                     // font
 {   VText	*text = [VText textGraphic];
     NSRect	r;
 
