@@ -1,11 +1,14 @@
 /* astroCommon.m
  * Common astronomical functions
  *
- * Copyright (C) 1998-2014 by Cenon GmbH
+ * Copyright (C) 1998-2015 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-11-06
- * modified: 2009-04-08 (modulo())
+ * modified: 2015-12-30 (sunNode(): float->double)
+ *           2015-06-07 (cenJDFromNSDate(), cenIntDateFromJD() added)
+ *           2015-03-30 (vhfJDFromNSDate() calendar released)
+ *           2009-04-08 (modulo())
  *           2006-04-06 (Pholus ']' added, Pallas '[' corrected, new astro functions without NSCalendarDate)
  *
  * This program is free software; you can redistribute it and/or
@@ -40,10 +43,10 @@
  * Intersection between the Sun's equator and the ecliptic.
  * the descending node is always 180 degree to the ascending node.
  */
-float sunNode(int year)
+double sunNode(int year)
 {
-    return 73.66670 + (float)(year - 1850) * 0.01396;   // 2014 = 75.956
-    //return 75.76  + (float)(year - 2000) * 0.01397;   // 2014 = 75.955
+    return 73.66670 + (double)(year - 1850) * 0.01396;   // 2014 = 75.956, 2016 = 75.98406
+    //return 75.76  + (double)(year - 2000) * 0.01397;   // 2014 = 75.955
 }
 
 /* ascending invariable node
@@ -52,7 +55,7 @@ float sunNode(int year)
 double invariableNode(int year)
 {
     //return 107.5822;    // J2000
-    return 102.95833 + (double)(year - 1750) * 0.01849548;  //1750 = 102.95833;
+    return 102.95833 + (double)(year - 1750) * 0.01849548;  //1750 = 102.95833, 2016 = 107.878
 }
 
 
@@ -434,9 +437,33 @@ double vhfSideralTimeMJD(double mjd, float lon)
 }
 
 
+/* Julian day from NSCalendarDate (starting -4712)
+ */
+double cenJD(int year, int month, int day, int H, int M, int S)
+{   double	hour  = (double)H+M/60.0+S/3600.0;
+    double  y0, y1, jd;
+
+    if ( month <= 2 )
+    {   month += 12;
+        year--;
+    }
+    y0 = year;
+    jd = floor((y0+4712.0)*365.25) + floor(30.6*(month+1.0)+0.000001) + day + hour/24.0 - 63.5;
+
+    y1 = Abs(year)/100 - Abs(year)/400;
+    if (year < 0)
+        y1 = -y1;
+    jd = jd - y1 + 2.0;
+    if ((year < 0) && (y0/100.0 == floor(y0/100.0)) && (y0/400.0 != floor(y0/400.0)))
+        jd -= 1.0;
+
+    return jd;
+}
+
 /* Julian day from NSDate (starting -4712)
  */
-double vhfJDFromNSDate(NSDate *date)
+double vhfJDFromNSDate(NSDate *date)    { return cenJDFromNSDate(date); }
+double cenJDFromNSDate(NSDate *date)
 {   NSCalendar          *calendar = [[NSCalendar alloc] initWithCalendarIdentifier:NSGregorianCalendar];
     unsigned            unitFlags = NSYearCalendarUnit | NSMonthCalendarUnit |  NSDayCalendarUnit
                                   | NSHourCalendarUnit | NSMinuteCalendarUnit| NSSecondCalendarUnit;
@@ -465,6 +492,7 @@ double vhfJDFromNSDate(NSDate *date)
     if ((year < 0) && (y0/100.0 == floor(y0/100.0)) && (y0/400.0 != floor(y0/400.0)))
         jd -= 1.0;
 
+    [calendar release];
     return jd;
 }
 
@@ -528,7 +556,9 @@ double vhfJulianDayFromInt(int yyyymmdd, int hhmm)
 }
 /* date from Julian day (starting -4712)
  */
-int vhfIntDateFromJulianDay(double jd, int *yyyymmdd, int *hhmm)
+int cenIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm) { return cenIntDateFromJD(jd, yymmdd, hhmm); }
+int vhfIntDateFromJulianDay(double jd, int *yymmdd, int *hhmm) { return cenIntDateFromJD(jd, yymmdd, hhmm); }   // DEPRECATED
+int cenIntDateFromJD (double jd, int *yyyymmdd, int *hhmm)
 {   int		year, month, day, yymmdd;
     double	u0, u1, u2, u3, u4, hour;
 
@@ -556,6 +586,34 @@ int vhfIntDateFromJulianDay(double jd, int *yyyymmdd, int *hhmm)
     return yymmdd;
 }
 
+NSDate *cenNSDateFromJulianDay(double jd) { return cenNSDateFromJD(jd); }
+NSDate *cenNSDateFromJD(double jd)
+{   int		y, m, d, H, M, S;
+    double	u0, u1, u2, u3, u4, hour;
+
+    u0 = jd + 32082.5;
+    u1 = u0 + floor(u0/36525.0) - floor(u0/146100.0) - 38.0;
+    if (jd >= 1830691.5)
+        u1 += 1;
+    u0 = u0 + floor(u1/36525.0) - floor(u1/146100.0) - 38.0;
+
+    u2 = floor(u0 + 123.0);
+    u3 = floor((u2 - 122.2) / 365.25);
+    u4 = floor((u2 - floor(365.25 * u3) ) / 30.6001);
+    m = (int)(u4 - 1.0);
+    if (m > 12)
+        m -= 12;
+    d = (int) (u2 - floor(365.25 * u3) - floor(30.6001 * u4));
+    y = (int) (u3 + floor((u4 - 2.0) / 12.0) - 4800);
+    hour = (jd - floor(jd + 0.5) + 0.5) * 24.0;
+    H = (int)hour;
+    M = (int)((hour-(double)H)*60.0);
+    S = (int)((hour-(double)H-(double)M/60.0)*3600.0);
+
+    return [NSDate dateWithString:[NSString stringWithFormat:@"%d-%s%d-%s%d %s%d:%s%d:%s%d +0000",
+                                   y, (m<10)?"0":"", m, (d<10)?"0":"", d,
+                                   (H<10)?"0":"", H, (M<10)?"0":"", M, (S<10)?"0":"", S]];
+}
 NSCalendarDate *vhfNSDateFromJD(double jd)
 {   int		y, m, d, H, M, S;
     double	u0, u1, u2, u3, u4, hour;
@@ -1161,7 +1219,7 @@ double mod360(double deg)
         deg += 360.0;
     return deg;
 }
-/* put angle within [0, 359.999]
+/* put angle within [0, 359.999] = modulo(360)
  */
 double standardAngle( double angle )	// same as angle
 {
@@ -1181,7 +1239,7 @@ double angle180( double deg1, double deg2 )
         ang = 360.0 - ang;
     return ang;
 }
-/* angle = object1 - object2
+/* angle = modulo(object1 - object2, 360)
  */
 double angle( double deg1, double deg2 )
 {   double angle = deg1 - deg2;
